==> common-configuration-1.0.1-sources.jar: be/yildizgames/common/configuration/FileConfigurationRetriever.java <==
/*
 *
 * This file is part of the Yildiz-Engine project, licenced under the MIT License  (MIT)
 *
 * Copyright (c) 2018 Grégory Van den Borre
 *
 * More infos available: https://www.yildiz-games.be
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy of this software and associated
 * documentation files (the "Software"), to deal in the Software without restriction, including without
 * limitation the rights to use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies
 * of the Software, and to permit persons to whom the Software is furnished to do so,
 * subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in all copies or substantial
 *  portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE
 *  WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS
 * OR COPYRIGHT  HOLDERS BE LIABLE FOR ANY CLAIM,
 *  DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE  SOFTWARE.
 *
 *
 */

package be.yildizgames.common.configuration;

import be.yildizgames.common.configuration.parameter.ApplicationArgs;
import be.yildizgames.common.configuration.parameter.DefaultArgName;
import be.yildizgames.common.exception.implementation.ImplementationException;
import be.yildizgames.common.file.FileProperties;
import be.yildizgames.common.file.exception.FileMissingException;
import be.yildizgames.common.logging.LogEngineProvider;
import be.yildizgames.common.logging.PreLogger;

import java.nio.file.Paths;
import java.util.Optional;
import java.util.Properties;

class FileConfigurationRetriever implements ConfigurationRetriever {

    private final PreLogger preLogger = LogEngineProvider.getLoggerProvider().getLogEngine().getPrelogger();

    private final ConfigurationNotFoundStrategy notFoundStrategy;

    FileConfigurationRetriever(ConfigurationNotFoundStrategy strategy) {
        super();
        ImplementationException.throwForNull(strategy);
        this.notFoundStrategy = strategy;
    }

    @Override
    public Properties retrieveFromArgs(ApplicationArgs args) {
        ImplementationException.throwForNull(args);
        Optional<String> path = args.getArg(DefaultArgName.CONFIGURATION_FILE);
        if(path.isEmpty()) {
            this.preLogger.error("Configuration file not found, no application arg provider with 'configuration' key");
            return this.notFoundStrategy.notFound();
        }
        try {
            return FileProperties.getPropertiesFromFile(Paths.get(path.get()));
        } catch (FileMissingException e) {
            this.preLogger.error("Configuration file not found" , e);
            return this.notFoundStrategy.notFound();
        }
    }
}

==> common-configuration-1.0.4-sources.jar: be/yildizgames/common/configuration/FileConfigurationRetriever.java <==
/*
 *
 * This file is part of the Yildiz-Engine project, licenced under the MIT License  (MIT)
 *
 * Copyright (c) 2019 Grégory Van den Borre
 *
 * More infos available: https://engine.yildiz-games.be
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy of this software and associated
 * documentation files (the "Software"), to deal in the Software without restriction, including without
 * limitation the rights to use, copy, modify, merge, publish, distribute, sublicense, and/or sell copies
 * of the Software, and to permit persons to whom the Software is furnished to do so,
 * subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in all copies or substantial
 *  portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR IMPLIED, INCLUDING BUT NOT LIMITED TO THE
 *  WARRANTIES OF MERCHANTABILITY, FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE AUTHORS
 * OR COPYRIGHT  HOLDERS BE LIABLE FOR ANY CLAIM,
 *  DAMAGES OR OTHER LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE  SOFTWARE.
 *
 *
 */

package be.yildizgames.common.configuration;

import be.yildizgames.common.configuration.parameter.ApplicationArgs;
import be.yildizgames.common.configuration.parameter.DefaultArgName;
import be.yildizgames.common.exception.implementation.ImplementationException;
import be.yildizgames.common.file.FileProperties;
import be.yildizgames.common.file.exception.FileMissingException;
import be.yildizgames.common.logging.LogEngineProvider;
import be.yildizgames.common.logging.PreLogger;

import java.io.IOException;
import java.nio.file.FileSystems;
import java.nio.file.Path;
import java.nio.file.Paths;
import java.nio.file.WatchKey;
import java.nio.file.WatchService;
import java.util.ArrayList;
import java.util.List;
import java.util.Optional;
import java.util.Properties;
import java.util.concurrent.TimeUnit;

import static java.nio.file.StandardWatchEventKinds.ENTRY_MODIFY;

class FileConfigurationRetriever implements ConfigurationRetriever {

    private final PreLogger preLogger = LogEngineProvider.getLoggerProvider().getLogEngine().getPrelogger();

    private final ConfigurationNotFoundStrategy notFoundStrategy;

    FileConfigurationRetriever(ConfigurationNotFoundStrategy strategy) {
        super();
        ImplementationException.throwForNull(strategy);
        this.notFoundStrategy = strategy;
    }

    @Override
    public Properties retrieveFromArgs(ApplicationArgs args) {
        ImplementationException.throwForNull(args);
        Optional<String> path = args.getArg(DefaultArgName.CONFIGURATION_FILE);
        if(path.isEmpty()) {
            this.preLogger.error("Configuration file not found, no application arg provider with 'configuration' key");
            return this.notFoundStrategy.notFound();
        }
        Properties properties;
        try {
            Path configPath = Paths.get(path.get());
            properties = FileProperties.getPropertiesFromFile(configPath);
            ReloadableConfiguration reloadableConfiguration = new ReloadableConfiguration(properties, args);
            return properties;
        } catch (FileMissingException e) {
            this.preLogger.error("Configuration file not found" , e);
            return this.notFoundStrategy.notFound();
        }
    }
}
